@@ -28,7 +28,7 @@ class DatabaseConnection:
         self.db_password = self.config.get("db-password", None)
         self.db_database = self.config.get("db-database", None)
         self.db = None
-        self.connstr = f"postgres://{redact(self.db_password)}:{self.db_username}@{self.db_hostname}:{self.db_port}/{self.db_database}"
+        self.connstr = f"postgres://{self.db_username}:{redact(self.db_password)}@{self.db_hostname}:{self.db_port}/{self.db_database}"
         logger.info(f"DATABASE: {self.connstr}")
         self.connection_error = None
         self._prepare_db()
